//----------------------------------------------------------------------------
/*
 * File: btn.h
 * - header file for btn.c
 * 
 * Part of Emulation of PMD 32 drive.
 * Based on MMC/SD/SDHC card library by Roland Riegel
 *   - http://www.roland-riegel.de/sd-reader/
 *
 * Author: Roman Brik { pmd85emu (at) gmail.com }
 * Web: http://pmd85.borik.net
 * Date: 15 Sep 2009
 * Version 1.3
*/
//----------------------------------------------------------------------------
#ifndef __BTN_H__
#define __BTN_H__
//----------------------------------------------------------------------------
#define BTN_PORT_CTRL           DDRA
#define BTN_PORT_DATA           PORTA
#define BTN_PORT_PIN            PINA

#define BTN_CANCEL              _BV(3)
#define BTN_SET                 _BV(1)
#define BTN_LEFT                _BV(2)
#define BTN_RIGHT               _BV(0)

// button pins as input
#define BTN_PORT_DIR            ~(BTN_SET | BTN_CANCEL | BTN_LEFT | BTN_RIGHT)
// pull-up must be connected
#define BTN_PORT_PUP            (BTN_SET | BTN_CANCEL | BTN_LEFT | BTN_RIGHT)
// all buttons relesased
#define BTN_ALL_UP              (BTN_SET | BTN_CANCEL | BTN_LEFT | BTN_RIGHT)
// button must be held at least 100 ms
#define BTN_MIN_DELAY           (100 / TIMER_INTERVAL_MS)
// backlight off delay
#define BTN_BL_OFF_SEC          20
#define BTN_BL_OFF_DELAY        ((BTN_BL_OFF_SEC * 1000) / TIMER_INTERVAL_MS)
#if (BTN_BL_OFF_SEC == 0 || BTN_BL_OFF_SEC > 65)
  #error "Bad value of macro BTN_BL_OFF_SEC"
#endif
//----------------------------------------------------------------------------
void btn_init(void);
uint8_t btn_test(void);
uint8_t btn_read(void);
//----------------------------------------------------------------------------
#endif
//----------------------------------------------------------------------------
